.. _changelog:

#########
Changelog
#########

This document lists the changes made during each release of XRTpy,
including bug fixes and changes to the application programming interface
(API).

.. toctree::
   :maxdepth: 1

   dev
   0.4.0
   0.3.0
   0.2.0
